/*
 * Metadevices (RTC, meminfo, CPUinfo, shutdown)
 *
 * Copyright (C) 2003 Juha Aatrokoski, Timo Lilja,
 *   Leena Salmela, Teemu Takanen, Aleksi Virtanen.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above
 *    copyright notice, this list of conditions and the following
 *    disclaimer in the documentation and/or other materials provided
 *    with the distribution.
 * 3. The name of the author may not be used to endorse or promote
 *    products derived from this software without specific prior
 *    written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 * GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * $Id: metadev.h,v 1.2 2003/05/21 18:12:24 ttakanen Exp $
 *
 */

#ifndef DRIVERS_METADEV_H
#define DRIVERS_METADEV_H

#include "lib/types.h"
#include "drivers/yams.h"
#include "drivers/device.h"

#define DEFAULT_SHUTDOWN_MAGIC 0xdeadc0de
#define POWEROFF_SHUTDOWN_MAGIC 0x0badf00d

device_t *rtc_init(io_descriptor_t *desc);
uint32_t rtc_get_msec(void);
uint32_t rtc_get_clockspeed(void);

device_t *meminfo_init(io_descriptor_t *desc);
uint32_t meminfo_get_pages(void);

device_t *cpustatus_init(io_descriptor_t *desc);
int cpustatus_count(void);
void cpustatus_generate_irq(device_t *dev, int irqtype);

device_t *shutdown_init(io_descriptor_t *desc);
void shutdown(uint32_t magic);

#endif /* DRIVERS_METADEV_H */



